.. _Part2:

----------------------
Repository development
----------------------

This part is about developing applications with the *CubicWeb*
framework. It is not concerned with the web system, which is a
separate layer and has its own whole chapter.

.. toctree::
   :maxdepth: 2
   :numbered:

   cubes/index
   vreg.rst
   datamodel/index
   entityclasses/index
   devcore/index
   repo/index
   testing.rst
   migration.rst
   profiling.rst
